X-Git-Url: https://git.saurik.com/wxWidgets.git/blobdiff_plain/15d521a109c4de5b2e18bb7b953bfedd5505a1ee..e5cfb314ae1cadac46cc50d37d9f6d15d8260a29:/include/wx/cocoa/dcscreen.h

diff --git a/include/wx/cocoa/dcscreen.h b/include/wx/cocoa/dcscreen.h
index f6e08fd043..cd00c5528e 100644
--- a/include/wx/cocoa/dcscreen.h
+++ b/include/wx/cocoa/dcscreen.h
@@ -1,26 +1,27 @@
 /////////////////////////////////////////////////////////////////////////////
 // Name:        wx/cocoa/dcscreen.h
 // Purpose:     wxScreenDC class
 // Author:      David Elliott
 // Modified by:
 // Created:     2003/03/16
-// RCS-ID:      $Id:
+// RCS-ID:      $Id$
 // Copyright:   (c) 2003 David Elliott
-// Licence:   	wxWindows license
+// Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
 #ifndef __WX_COCOA_DCSCREEN_H__
 #define __WX_COCOA_DCSCREEN_H__
 
-#include "wx/dcclient.h"
+#include "wx/dcscreen.h"
+#include "wx/cocoa/dc.h"
 
-class WXDLLEXPORT wxScreenDC: public wxDC
+class WXDLLIMPEXP_CORE wxScreenDCImpl: public wxCocoaDCImpl
 {
-    DECLARE_DYNAMIC_CLASS(wxScreenDC)
+    DECLARE_DYNAMIC_CLASS(wxScreenDCImpl)
 public:
-    wxScreenDC(void);
-    wxScreenDC( wxDC *dc ); // Create compatible DC
-    ~wxScreenDC(void);
+    wxScreenDCImpl(wxScreenDC *owner);
+    wxScreenDCImpl(wxScreenDC *owner, wxDC *dc ); // Create compatible DC
+    virtual ~wxScreenDCImpl(void);
 
     // Compatibility with X's requirements for drawing on top of all windows
     static bool StartDrawingOnTop(wxWindow* WXUNUSED(window)) { return true; }
@@ -1,26 +1,27 @@
 /////////////////////////////////////////////////////////////////////////////
 // Name:        wx/cocoa/dcscreen.h
-// Purpose:     wxScreenDC class
+// Purpose:     wxScreenDCImpl class
 // Author:      David Elliott
 // Modified by: